﻿using System;
using System.Windows.Forms;
using System.IO;
using System.Drawing;
using System.Collections.Generic;
using STFXmlParser;
using Selections;

namespace CalcHelper
{
    public partial class Form1 : Form
    {
        /*
         * Called From:
         * 
         *      SetupPdf1()
         *      SetupPdf2()
         *      
         * We just opened a file and set the box page lists in Field.cs
         * which are lists of page numbers that pertain to boxes such as
         * checkboxes, code39 barcode boxes, etc.. We will allow the user
         * to be able to limit navigation to these. We also built a page
         * list for pages that have boxes on them.
         * 
         * All page navigation menu items are disabled in the designer as
         * some documents may not have any 2D barcodes on them for example.
         * Any that are enabled will allow the user to navigate to just
         * those pages so they do not have to 'page-flip' looking for say,
         * checkboxes.
         */
        public void EnablePageNavMenuItems(string pdfId, ref PageArray pa)
        {
            if (pa == null)
            {
                using (MessageForm mainMsg = new MessageForm(MessageForm.msgIcon.error, "null PageArray argument:\n\nEnablePageNavMenuItems() received a null pa argument."))
                {
                    mainMsg.ShowDialog(this);
                }

                return;
            }

            switch (pdfId)
            {
                case ("pdf1"):

                    /*
                     * Pages with boxes on them. Checking for > 0 due to the RARE case
                     * of only 1 page with one box which is box1_65535 which I do not
                     * store in the dictionary, so this list would be empty. I do not
                     * count box1_65535 as a box'.
                     */
                    if (pa.GetBoxedPageListCount("boxedpages") > 0)
                    {
                        boxedPageToolStripMenuItem.Enabled = true;
                    }

                    if (pa.GetBoxedPageListCount("checkbox") > 0)
                    {
                        chkboxPageToolStripMenuItem.Enabled = true;
                    }

                    if (pa.GetBoxedPageListCount("code39") > 0)
                    {
                        code39ToolStripMenuItem.Enabled = true;
                    }

                    if (pa.GetBoxedPageListCount("int2of5") > 0)
                    {
                        int2of5ToolStripMenuItem.Enabled = true;
                    }

                    if (pa.GetBoxedPageListCount("pdf417") > 0)
                    {
                        pdf417ToolStripMenuItem.Enabled = true;
                    }

                    if (pa.GetBoxedPageListCount("qrcode") > 0)
                    {
                        qrCodesToolStripMenuItem.Enabled = true;
                    }

                    break;

                case ("pdf2"):

                    if (pa.GetBoxedPageListCount("boxedpages") > 0)
                    {
                        boxedPageToolStripMenuItem2.Enabled = true;
                    }

                    if (pa.GetBoxedPageListCount("checkbox") > 0)
                    {
                        chkboxToolStripMenuItem2.Enabled = true;
                    }

                    if (pa.GetBoxedPageListCount("code39") > 0)
                    {
                        code39ToolStripMenuItem2.Enabled = true;
                    }

                    if (pa.GetBoxedPageListCount("int2of5") > 0)
                    {
                        int2of5ToolStripMenuItem2.Enabled = true;
                    }

                    if (pa.GetBoxedPageListCount("pdf417") > 0)
                    {
                        pdf417ToolStripMenuItem2.Enabled = true;
                    }

                    if (pa.GetBoxedPageListCount("qrcode") > 0)
                    {
                        qrCodesToolStripMenuItem2.Enabled = true;
                    }

                    break;
            }
        }
    }
}